@@ -47,7 +47,7 @@ YLocale::YLocale(char const * localeName) {
                "Falling back to 'C' locale'."));
         fLocaleName = setlocale(LC_ALL, "C");
     }
-#warning "should always use multibyte/fontset if I18N"
+/// TODO #warning "should always use multibyte/fontset if I18N"
     multiByte = (MB_CUR_MAX > 1);
 
     char const * codeset = NULL;
@@ -71,7 +71,7 @@ YLocale::YLocale(char const * localeName) {
          "multibyte: %d, codeset: %s, endian: %c",
          fLocaleName, MB_CUR_MAX, multiByte, codeset, endian.c ? 'b' : 'l'));
 
-#warning "this is getting way too complicated"
+/// TODO #warning "this is getting way too complicated"
 
     char const * unicodeCharsets[] = {
 #ifdef CONFIG_UNICODE_SET
@@ -152,7 +152,7 @@ YUChar *YLocale::unicodeString(const YLChar *lStr, size_t const lLen,
     char * inbuf((char *) lStr), * outbuf((char *) uStr);
     size_t inlen(lLen), outlen(4 * lLen);
 
-    if (0 > (int) iconv(instance->toUnicode, &inbuf, &inlen, &outbuf, &outlen))
+    if (0 > (int) iconv(instance->toUnicode, const_cast<const char **>(&inbuf), &inlen, &outbuf, &outlen))
         warn(_("Invalid multibyte string \"%s\": %s"), lStr, strerror(errno));
 
     *((YUChar *) outbuf) = 0;
